// page 1 - Battery voltage, actual current (Amperes), max. current (Amperes),
// flight time, height

void show_1() {
  if (page != pageTmp) {
    show_1_init();
  }

  send_msp(MSP_STATUS, 0, 0);
  readData();

  uint16_t cycleTime = readUInt16(inBuf, 0); // parse Cycle Time data
  if (cycleTime != varTmp[0]) {
    tft.fillRect(CYCLETIME_X + 36, CYCLETIME_Y, 24, 7, ST7735_BLACK);
    tft.setCursor(CYCLETIME_X + 36, CYCLETIME_Y);
    tft.print(cycleTime, DEC);
    varTmp[0] = cycleTime;
  }

  uint16_t i2cErr = readUInt16(inBuf, 2); // parse I2C errors counter data
  if (i2cErr != varTmp[1]) {
    tft.fillRect(I2CERR_X + 50, I2CERR_Y, 24, 7, ST7735_BLACK);
    tft.setCursor(I2CERR_X + 50, I2CERR_Y);
    tft.print(i2cErr, DEC);
    varTmp[1] = i2cErr;
  }

  uint16_t sensors = readUInt16(inBuf, 4); // parse list of available sensors
  tft.setCursor(SENSORS_X, SENSORS_Y);
  tft.print("Sensor: ");
  if (bitRead(sensors, 1)) {
    tft.print("BARO ");
  }
  if (bitRead(sensors, 2)) {
    tft.print("MAG ");
  }
  if (bitRead(sensors, 3)) {
    tft.print("GPS ");
  }
  if (bitRead(sensors, 4)) {
    tft.print("SONAR ");
  }

  send_msp(MSP_ANALOG, 0, 0);
  readData();

  uint8_t  vbat = inBuf[0];
  if (vbat != varTmp[2]) {
    tft.fillRect(VBAT_X + 32, VBAT_Y, 18, 7, ST7735_BLACK);
    tft.setCursor(VBAT_X + 32, VBAT_Y);
    tft.print(vbat, DEC);
    varTmp[2] = vbat;
  }

  uint16_t powerSum = readUInt16(inBuf, 1);
  if (powerSum != varTmp[3]) {
    tft.fillRect(POWERSUM_X + 45, POWERSUM_Y, 18, 7, ST7735_BLACK);
    tft.setCursor(POWERSUM_X + 45, POWERSUM_Y);
    tft.print(powerSum, DEC);
    varTmp[3] = powerSum;
  }

  uint16_t rssi = readUInt16(inBuf, 3);
  if (rssi != varTmp[4]) {
    tft.fillRect(RSSI_X + 32, RSSI_Y, 18, 7, ST7735_BLACK);
    tft.setCursor(RSSI_X + 32, RSSI_Y);
    tft.print(rssi, DEC);
    varTmp[4] = rssi;
  }

  if (dataSize > 5) {
    uint16_t amps = readUInt16(inBuf, 5);
    if (amps != varTmp[5]) {
      tft.fillRect(AMPS_X + 32, AMPS_Y, 25, 7, ST7735_BLACK);
      tft.setCursor(AMPS_X + 32, AMPS_Y);
      tft.print(amps, DEC);
      varTmp[5] = amps;
    }
  }
  else { // amps not implemented
    tft.setCursor(AMPS_X + 32, AMPS_Y);
    tft.print("---");
  }

  // Powered time counter
  if (Minutes != varTmp[6]) {  // if minutes changed
    tft.fillRect(TIMER_X + 47, TIMER_Y, 12, 7, ST7735_BLACK); // clear old timer data on display
    tft.setCursor(TIMER_X + 47, TIMER_Y);
    if (Minutes < 10) {
      tft.print("0");
    }
    tft.print(Minutes);
    tft.print(":");
    varTmp[6] = Minutes;
  }

  if (Seconds != varTmp[7]) {
    tft.fillRect(TIMER_X + 65, TIMER_Y, 12, 7, ST7735_BLACK); // clear old timer data on display
    tft.setCursor(TIMER_X + 65, TIMER_Y);
    if (Seconds < 10) {
      tft.print("0");
    }
    tft.print(Seconds);
    varTmp[7] = Seconds;
  }

  // Armed time counter
  if (ArmSeconds != ArmSecondsTmp) {
    tft.fillRect(TIMER_ARM_X + 34, TIMER_ARM_Y, 30, 7, ST7735_BLACK); // clear old timer data on display
    tft.setCursor(TIMER_ARM_X + 52, TIMER_ARM_Y);
    uint8_t ArmSecNow = (ArmSeconds) % 60;
    if (ArmSecNow < 10) {
      tft.print("0");
    }
    tft.print(ArmSecNow);

    uint8_t ArmMinutes = (ArmSeconds / 60UL) % 60;
    tft.setCursor(TIMER_ARM_X + 34, TIMER_ARM_Y);
    if (ArmMinutes < 10) {
      tft.print("0");
    }
    tft.print(ArmMinutes);
    tft.print(":");

    ArmSecondsTmp = ArmSeconds;
  }

  checkArm(); // show the red bar if armed

}

void show_1_init() {
  pageTmp = page;
  ArmSecondsTmp = -1;
  varTmp[1] = -1;
  varTmp[2] = -1;
  varTmp[3] = -1;
  varTmp[4] = -1;
  varTmp[5] = -1;
  varTmp[6] = 100;

  tft.fillScreen(ST7735_BLACK);  // clear display to black
  tft.setTextColor(ST7735_WHITE);

  tft.setCursor(PAGE_NAME_X, PAGE_NAME_Y);
  tft.print("STATUS");

  tft.setCursor(PAGE_NUM_X, PAGE_NUM_Y);
  tft.print(page, DEC);
  tft.print("/");
  tft.print(TOTAL_PAGE, DEC);

  send_msp(MSP_IDENT, 0, 0);
  readData();
  uint8_t MWver = inBuf[0];
  uint8_t MWtype = inBuf[1];
  uint8_t MSPver = inBuf[2];

  tft.setCursor(VERSION_X, VERSION_Y);
  tft.print("Ver.");
  tft.print(MWver);

  tft.setCursor(MULTITYPE_X, MULTITYPE_Y);
  tft.print("Type:");

  switch (MWtype) {
    case 1: tft.print("TRI"); break;
    case 2: tft.print("QUADP"); break;
    case 3: tft.print("QUADX"); break;
    case 4: tft.print("BI"); break;
    case 5: tft.print("GIMBAL"); break;
    case 6: tft.print("Y6"); break;
    case 7: tft.print("HEX6"); break;
    case 8: tft.print("FLWING"); break;
    case 9: tft.print("Y4"); break;
    case 10: tft.print("HEX6X"); break;
    case 11: tft.print("OCTOX8"); break;
    case 12: tft.print("OCTOFLATP"); break;
    case 13: tft.print("OCTOFLATX"); break;
    case 14: tft.print("AIRPLANE"); break;
    case 15: tft.print("HELI_120_CCPM"); break;
    case 16: tft.print("HELI_90_DEG"); break;
    case 17: tft.print("VTAIL4"); break;
    case 18: tft.print("HEX6H"); break;
    default: tft.print("????");
  }

  tft.setCursor(CYCLETIME_X, CYCLETIME_Y);
  tft.print("Cycle:");

  tft.setCursor(I2CERR_X, I2CERR_Y);
  tft.print("I2C err:");

  tft.setCursor(VBAT_X, VBAT_Y);
  tft.print("Vbat:");

  tft.setCursor(AMPS_X, AMPS_Y);
  tft.print("Amps:");

  tft.setCursor(POWERSUM_X, POWERSUM_Y);
  tft.print("PwrSum:");

  tft.setCursor(RSSI_X, RSSI_Y);
  tft.print("RSSI:");

  tft.setCursor(TIMER_X, TIMER_Y);
  tft.print("Powered");

  tft.setCursor(TIMER_ARM_X, TIMER_ARM_Y);
  tft.print("Armed");
}

